@@ -28,14 +28,14 @@ import json
 from bids.layout import BIDSLayout
 from .build_workflow import init_dwi_recon_workflow
 from .anatomical import init_recon_anatomical_wf
-from .interchange import anatomical_input_fields
+from .interchange import anatomical_workflow_outputs
 
 LOGGER = logging.getLogger('nipype.workflow')
 
 
 def init_qsirecon_wf(subject_list, run_uuid, work_dir, output_dir, recon_input,
-                     recon_spec, low_mem, omp_nthreads, sloppy,
-                     name="qsirecon_wf"):
+                     recon_spec, low_mem, omp_nthreads, sloppy, freesurfer_input,
+                     b0_threshold, name="qsirecon_wf"):
     """
     This workflow organizes the execution of qsiprep, with a sub-workflow for
     each subject.
@@ -52,7 +52,10 @@ def init_qsirecon_wf(subject_list, run_uuid, work_dir, output_dir, recon_input,
                               recon_spec='doctest_spec.json',
                               output_dir='.',
                               low_mem=False,
-                              omp_nthreads=1)
+                              freesurfer_input="freesurfer",
+                              sloppy=False,
+                              omp_nthreads=1,
+                              )
 
 
     Parameters
@@ -72,6 +75,8 @@ def init_qsirecon_wf(subject_list, run_uuid, work_dir, output_dir, recon_input,
             Path to a JSON file that specifies how to run reconstruction
         low_mem : bool
             Write uncompressed .nii files in some cases to reduce memory usage
+        freesurfer_input : Pathlib.Path
+            Path to the directory containing subject freesurfer outputs ($SUBJECTS_DIR)
         sloppy : bool
             If True, replace reconstruction options with fast but bad options.
     """
@@ -89,7 +94,9 @@ def init_qsirecon_wf(subject_list, run_uuid, work_dir, output_dir, recon_input,
             output_dir=output_dir,
             omp_nthreads=omp_nthreads,
             low_mem=low_mem,
-            sloppy=sloppy
+            sloppy=sloppy,
+            b0_threshold=b0_threshold,
+            freesurfer_input=freesurfer_input
             )
 
         single_subject_wf.config['execution']['crashdump_dir'] = (os.path.join(
@@ -103,8 +110,8 @@ def init_qsirecon_wf(subject_list, run_uuid, work_dir, output_dir, recon_input,
 
 
 def init_single_subject_wf(
-        subject_id, name, reportlets_dir, output_dir,
-        low_mem, omp_nthreads, recon_input, recon_spec, sloppy):
+        subject_id, name, reportlets_dir, output_dir, freesurfer_input,
+        low_mem, omp_nthreads, recon_input, recon_spec, sloppy, b0_threshold):
     """
     This workflow organizes the reconstruction pipeline for a single subject.
     Reconstruction is performed using a separate workflow for each dwi series.
@@ -123,6 +130,8 @@ def init_single_subject_wf(
             Directory in which to save reportlets
         output_dir : str
             Directory in which to save derivatives
+        freesurfer_input : Pathlib.Path
+            Path to the directory containing subject freesurfer outputs ($SUBJECTS_DIR)
         recon_input : str
             Root directory of the output from qsiprep
         recon_spec : str
@@ -152,6 +161,7 @@ def init_single_subject_wf(
                 raise Exception(
                     "Unable to find subject directory in %s or %s" % (
                         recon_input, qp_recon_input))
+            recon_input = qp_recon_input
 
         spec = _load_recon_spec(recon_spec, sloppy=sloppy)
         space = spec['space']
@@ -193,38 +203,44 @@ to workflows in *qsiprep*'s documentation]\
         LOGGER.info("No dwi files found for %s", subject_id)
         return workflow
 
-    # Was there a forced normalization during preprocessing?
-    template_transform = [f.path for f in
-                          layout.get(subject=subject_id, suffix='xfm', extension=['.h5'])
-                          if 'to-T1w' in f.path and 'from-MNI152NLin2009cAsym' in f.path]
-    if template_transform:
-        template_transform = template_transform[0]
-        has_transform = True
-    else:
-        has_transform = False
+    anat_ingress_wf, available_anatomical_data = init_recon_anatomical_wf(
+        subject_id=subject_id,
+        recon_input_dir=recon_input,
+        extras_to_make=spec.get('anatomical', []),
+        freesurfer_dir=freesurfer_input,
+        name='anat_ingress_wf')
+    
+    # Fill-in datasinks and reportlet datasinks for the anatomical workflow
+    for _node in anat_ingress_wf.list_node_names():
+        node_suffix = _node.split('.')[-1]
+        if node_suffix.startswith('ds_'):
+            node = anat_ingress_wf.get_node(_node)
+            node.inputs.source_file = "anat/sub-{}_desc-preproc_T1w.nii.gz".format(subject_id)
+            if "report" in node_suffix:
+                node.inputs.base_directory = reportlets_dir
+            else:
+                node.inputs.base_directory = output_dir
+    
+    # Connect the anatomical-only inputs. NOTE this is not to the inputnode!
+    LOGGER.info("Anatomical (T1w) available for recon: %s", available_anatomical_data)
+    to_connect = [('outputnode.' + name, 'qsirecon_anat_wf.inputnode.' + name) 
+                  for name in anatomical_workflow_outputs]
 
-    t1w_brain_mask = layout.get(subject=subject_id,
-                                invalid_filters='allow',
-                                desc='brain',
-                                extension=['nii', 'nii.gz'],
-                                modality='anat')
-    has_t1w_brain_mask = bool(t1w_brain_mask)
-
-    anat_ingress_wf = init_recon_anatomical_wf(subject_id=subject_id,
-                                               recon_input_dir=recon_input,
-                                               extras_to_make=spec.get('anatomical', []),
-                                               name='anat_ingress_wf')
-
-    to_connect = [('outputnode.' + name, 'inputnode.' + name) for name in anatomical_input_fields]
     # create a processing pipeline for the dwis in each session
-    dwi_recon_wf = init_dwi_recon_workflow(dwi_files=dwi_files,
-                                           workflow_spec=spec,
-                                           reportlets_dir=reportlets_dir,
-                                           output_dir=output_dir,
-                                           has_t1w=has_t1w_brain_mask,
-                                           has_t1w_transform=has_transform,
-                                           omp_nthreads=omp_nthreads)
-    workflow.connect([(anat_ingress_wf, dwi_recon_wf, to_connect)])
+    for dwi_file in dwi_files:
+
+        dwi_recon_wf = init_dwi_recon_workflow(
+            dwi_file=dwi_file,
+            available_anatomical_data=available_anatomical_data,
+            workflow_spec=spec,
+            sloppy=sloppy,
+            prefer_dwi_mask=False,
+            infant_mode=False,
+            b0_threshold=b0_threshold,
+            reportlets_dir=reportlets_dir,
+            output_dir=output_dir,
+            omp_nthreads=omp_nthreads)
+        workflow.connect([(anat_ingress_wf, dwi_recon_wf, to_connect)])
 
     return workflow
 
