@@ -10,9 +10,9 @@ import nipype.pipeline.engine as pe
 from nipype.interfaces import afni, utility as niu
 from qsiprep.interfaces.bids import ReconDerivativesDataSink
 from ...interfaces.dipy import BrainSuiteShoreReconstruction, MAPMRIReconstruction
-from .interchange import input_fields
+from .interchange import recon_workflow_input_fields
 from ...engine import Workflow
-from ...interfaces.reports import ReconPeaksReport
+from ...interfaces.reports import CLIReconPeaksReport
 
 LOGGER = logging.getLogger('nipype.interface')
 
@@ -38,7 +38,7 @@ def external_format_datasinks(output_suffix, params, wf):
         wf.connect(outputnode, 'fod_sh_mif', ds_mif, 'in_file')
 
 
-def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, has_transform, name="dipy_3dshore_recon",
+def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, available_anatomical_data, name="dipy_3dshore_recon",
                                         output_suffix="", params={}):
     """Reconstruct EAPs, ODFs, using 3dSHORE (brainsuite-style basis set).
 
@@ -94,7 +94,7 @@ def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, has_transform, name="dipy_
 
     """
 
-    inputnode = pe.Node(niu.IdentityInterface(fields=input_fields + ['odf_rois']),
+    inputnode = pe.Node(niu.IdentityInterface(fields=recon_workflow_input_fields + ['odf_rois']),
                         name="inputnode")
     outputnode = pe.Node(
         niu.IdentityInterface(
@@ -107,12 +107,10 @@ def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, has_transform, name="dipy_
     desc = """Dipy Reconstruction
 
 : """
-    resample_mask = pe.Node(
-        afni.Resample(outputtype='NIFTI_GZ', resample_mode="NN"), name='resample_mask')
     recon_shore = pe.Node(BrainSuiteShoreReconstruction(**params), name="recon_shore")
     doing_extrapolation = params.get("extrapolate_scheme") in ("HCP", "ABCD")
 
-    plot_peaks = pe.Node(ReconPeaksReport(), name='plot_peaks')
+    plot_peaks = pe.Node(CLIReconPeaksReport(), name='plot_peaks')
     ds_report_peaks = pe.Node(
         ReconDerivativesDataSink(extension='.png',
                                  desc="3dSHOREODF",
@@ -123,10 +121,8 @@ def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, has_transform, name="dipy_
     workflow.connect([
         (inputnode, recon_shore, [('dwi_file', 'dwi_file'),
                                   ('bval_file', 'bval_file'),
-                                  ('bvec_file', 'bvec_file')]),
-        (inputnode, resample_mask, [('t1_brain_mask', 'in_file'),
-                                    ('dwi_file', 'master')]),
-        (resample_mask, recon_shore, [('out_file', 'mask_file')]),
+                                  ('bvec_file', 'bvec_file'),
+                                  ('dwi_mask', 'mask_file')]),
         (recon_shore, outputnode, [('shore_coeffs_image', 'shore_coeffs_image'),
                                    ('rtop_image', 'rtop_image'),
                                    ('alpha_image', 'alpha_image'),
@@ -141,13 +137,13 @@ def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, has_transform, name="dipy_
                                    ('extrapolated_b', 'b_file')]),
         (inputnode, plot_peaks, [('dwi_ref', 'background_image'),
                                  ('odf_rois', 'odf_rois')]),
-        (resample_mask, plot_peaks, [('out_file', 'mask_file')]),
+        (inputnode, plot_peaks, [('dwi_mask', 'mask_file')]),
         (recon_shore, plot_peaks, [('odf_directions', 'directions_file'),
                                    ('odf_amplitudes', 'odf_file')]),
-        (plot_peaks, ds_report_peaks, [('out_report', 'in_file')])])
+        (plot_peaks, ds_report_peaks, [('peak_report', 'in_file')])])
 
     # Plot targeted regions
-    if has_transform:
+    if available_anatomical_data['has_qsiprep_t1w_transforms']:
         ds_report_odfs = pe.Node(
             ReconDerivativesDataSink(extension='.png',
                                      desc="3dSHOREODF",
@@ -246,7 +242,7 @@ def init_dipy_brainsuite_shore_recon_wf(omp_nthreads, has_transform, name="dipy_
     return workflow
 
 
-def init_dipy_mapmri_recon_wf(omp_nthreads, has_transform, name="dipy_mapmri_recon",
+def init_dipy_mapmri_recon_wf(omp_nthreads, available_anatomical_data, name="dipy_mapmri_recon",
                               output_suffix="", params={}):
     """Reconstruct EAPs, ODFs, using 3dSHORE (brainsuite-style basis set).
 
@@ -322,7 +318,7 @@ def init_dipy_mapmri_recon_wf(omp_nthreads, has_transform, name="dipy_mapmri_rec
             Default: None (cvxpy chooses its own solver)
     """
 
-    inputnode = pe.Node(niu.IdentityInterface(fields=input_fields + ['odf_rois']),
+    inputnode = pe.Node(niu.IdentityInterface(fields=recon_workflow_input_fields + ['odf_rois']),
                         name="inputnode")
     outputnode = pe.Node(
         niu.IdentityInterface(
@@ -337,7 +333,7 @@ def init_dipy_mapmri_recon_wf(omp_nthreads, has_transform, name="dipy_mapmri_rec
     recon_map = pe.Node(MAPMRIReconstruction(**params), name="recon_map")
     resample_mask = pe.Node(
         afni.Resample(outputtype='NIFTI_GZ', resample_mode="NN"), name='resample_mask')
-    plot_peaks = pe.Node(ReconPeaksReport(), name='plot_peaks')
+    plot_peaks = pe.Node(CLIReconPeaksReport(), name='plot_peaks')
     ds_report_peaks = pe.Node(
         ReconDerivativesDataSink(extension='.png',
                                  desc="MAPLMRIODF",
@@ -369,10 +365,10 @@ def init_dipy_mapmri_recon_wf(omp_nthreads, has_transform, name="dipy_mapmri_rec
                                  ('odf_rois', 'odf_rois')]),
         (recon_map, plot_peaks, [('odf_directions', 'directions_file'),
                                  ('odf_amplitudes', 'odf_file')]),
-        (plot_peaks, ds_report_peaks, [('out_report', 'in_file')])])
+        (plot_peaks, ds_report_peaks, [('peak_report', 'in_file')])])
 
     # Plot targeted regions
-    if has_transform:
+    if available_anatomical_data['has_qsiprep_t1w_transforms']:
         ds_report_odfs = pe.Node(
             ReconDerivativesDataSink(extension='.png',
                                      desc="MAPLMRIODF",
